# cmc-cs040-preslielampitt
 
![doctest](https://github.com/preslielampitt/llm-lab/actions/workflows/doctests.yml/badge.svg)
![integration-test](https://github.com/preslielampitt/llm-lab/actions/workflows/integration-tests.yml/badge.svg)
 
This lab sets up the code for the upcoming LLM project.

## This lab demonstrates:

1. How to write "test cases for your test cases"
2. How to get LLMs working in github actions
3. How to let other people "pip install" your projects
 
Available on PyPI: [cmc-cs040-preslielampitt](https://pypi.org/project/cmc-cs040-preslielampitt/)